'use strict';

const common = require('../common');

const options = [
  {
    flags: '-g, --group <column...>',
    description: 'You by the selected fields'
  }, {
    flags: '-d, --distinct',
    description: 'Add the distinct clause to the statement'
  }, {
    flags: '-r, --round [precision]',
    description: 'Round the result to a given precision'
  }, {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

const getSelection = (input, options) => {
  input = options.distinct
    ? `AVG(DISTINCT(${input}))`
    : `AVG(${input})`;
  input = (typeof options.round !== 'undefined')
    ? `ROUND(${input}, ${options.round === true
      ? 0
      : options.round})`
    : input;
  return options.group
    ? `${options.group},${input}`
    : input;
};

const getGroup = input => {
  return input
    ? `GROUP BY ${input}`
    : '';
};

module.exports = {
  name: 'average <columns> <table>',
  alias: 'avg',
  description: 'Return the average value of an expression.',
  before: [
    common.validateConnection,
    common.validateDatabase
  ],
  options: options,
  action: function(args, cb) {
    const {columns, table, options} = args;
    const selection = getSelection(columns, options);
    const group = getGroup(options.group);

    const query = `SELECT ${selection} FROM ${table} ${group}`;
    this.parent.query(query, options.db, cb, (results) => {
      this.log(`\n${common.printTable(results)}\n`);
      cb(null, results);
    });
  }
};
