"use strict";

const mysql = require("mysql");

const connReg = /^(\w+)@([\w.]+):(\d+)$/;
const questions = [
  {
    type: "input",
    name: "hostname",
    message: "Hostname: ",
    default: "localhost"
  }, {
    type: "input",
    name: "port",
    message: "Port: ",
    default: 3306,
    filter: v => parseInt(v)
  }, {
    type: "input",
    name: "username",
    message: "Username: "
  }, {
    type: "password",
    name: "password",
    message: "Password: "
  }
];

module.exports = {
  name: "connect",
  alias: "conn",
  description: "Connect to an existing host.",
  action: function(args, cb) {
    const {appData, localStorage, chalk} = this.parent;

    // If a last connection exist use it as defaults for questions
    const lastConnection = localStorage.getItem('last_connection');
    if (lastConnection) {
      const connDetails = connReg.exec(lastConnection);
      questions[0].default = connDetails[2];
      questions[1].default = connDetails[3];
      questions[2].default = connDetails[1];
    }

    this.log("\nEnter the connection informations:\n");

    // Get connection details
    return this.prompt(questions).then(answers => {
      const connString = `${answers.username}@${answers.hostname}:${answers.port}`;
      const conn = (this.parent.conn = mysql.createConnection({
        host: answers.hostname, 
        port: answers.port, 
        user: answers.username, 
        password: answers.password,
        multipleStatements: true
      }));

      // Attempt to connect
      conn.connect(err => {
        if (err) {
          return cb(`\n${err.message}\n`);
        }

        this.log(`\nYou have ${chalk.green('successfully')} connected.\n`);

        // Update session variables
        appData.currentUser = answers.username;
        appData.currentHost = answers.hostname;
        appData.currentPort = answers.port;

        // Override/store last used connection details
        localStorage.setItem('last_connection', connString);
        this.parent.refreshDelimiter();
        this.parent.listDatabases()
          .then(() => cb())
          .catch(() => cb());
      });
    });
  }
};
