'use strict';

const common = require('../common');

const options = [
  {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

const getSelection = input => {
  return (input !== '*' && input !== 'all')
    ? `${input},COUNT(*)`
    : 'COUNT(*)';
};

const getGroup = input => {
  return (input !== '*' && input !== 'all')
    ? `GROUP BY ${input}`
    : '';
};

module.exports = {
  name: 'count <columns> <table>',
  description: 'Count rows in a table',
  before: [
    common.validateConnection,
    common.validateDatabase
  ],
  options: options,
  action: function(args, cb) {
    const {columns, table, options} = args;

    const selection = getSelection(columns);
    const group = getGroup(columns);

    let query = `SELECT ${selection} FROM ${table} ${group}`;

    this.parent.query(query, options.db, cb, (results) => {
      this.log(`\n${common.printTable(results)}\n`);
      cb(null, results);
    });
  }
};
