'use strict';

const common = require('../common');

module.exports = {
  name: 'create database <name>',
  description: 'Create a new database',
  before: common.validateConnection,
  options: [{
    flags: '-u, --use',
    description: 'Select the database after creation'
  }],
  action: function(args, cb) {
    const {name} = args;
    const {appData, chalk} = this.parent;
    const colored = chalk.green(name);

    this.parent.query(`CREATE DATABASE ${name}`, null, cb, (data) => {
      this.log(`Database ${colored} has been created.`);
      appData.databases[name] = {tables: []};

      // Optionally use the newly created database
      if (args.options.use) {
        return this.parent.useDatabase(name)
          .then(() => cb(null, data))
          .catch(cb);
      }

      cb(null, data);
    });
  }
};
