'use strict';

const common = require('../common');
const app = require('../index');

// TODO: Support for multiple name arguments (variadic argument, multiple drop in one command)

module.exports = {
  name: 'drop database <name>',
  description: 'Drop the database or table',
  before: [
    common.validateConnection, 
    app.confirm('Do you really want to drop database %name%?')
  ],
  autocomplete: common.autoCompleteDatabases,
  action: function(args, cb) {
    const {name} = args;
    const {appData} = this.parent;
    const query = `DROP DATABASE IF EXISTS ${name}`;

    this.parent.query(query, null, cb, (results) => {
      this.log(`The database ${name} has been dropped.`);
      delete appData.databases[name];

      // If current database is the one that has been dropped
      // reset the delimiter and clear the currentDatabase variable
      if (appData.currentDatabase === name) {
        return this.parent.useDatabase()
          .then(() => cb(null, results))
          .catcH(cb);
      }

      cb(null, results);
    });
  }
};
