"use strict";

const common = require("../common");
const app = require("../index");

const options = [
  {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

module.exports = {
  name: "drop table <name>",
  description: "Drop the selected table.",
  options: options,
  autocomplete: common.autoCompleteTables,
  before: [
    common.validateConnection,
    app.confirm("Are you sure to drop the table %name%?")
  ],
  action: function(args, cb) {
    const {chalk} = this.parent;
    const {name, options} = args;
    const query = `DROP TABLE IF EXISTS ${name}`;

    this.parent.query(query, options.db, cb, (results) => {
      this.log(`\nThe table ${chalk.yellow(name)} has been dropped.\n`);
      cb(null, results);
    });
  }
};
