'use strict';

const fs = require('fs');
const path = require('path');
const common = require('../common');

const options = [
  {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

const validatePath = function(cmd, args) {
  return new Promise((resolve, reject) => {
    const {file} = args;
    const filePath = path.normalize(file);
    fs.access(filePath, fs.constants.R_OK, (err) => {
      if (err) {
        return reject('The file does not exist or is not readable.');
      }
      resolve();
    });
  });
};

module.exports = {
  name: 'load <file>',
  description: 'Count table records by column',
  before: [
    common.validateConnection,
    validatePath
  ],
  options: options,
  action: function(args, cb) {
    const {file: filePath} = args;
    const {appData, chalk} = this.parent;
    const database = options.db || appData.currentDatabase;

    fs.readFile(filePath, 'utf-8', (err, query) => {
      this.parent.query(query, database, cb, data => {
        this.log('\n', `The file has been ${chalk.green('loaded successfully')}.`, '\n');
        cb(null, data);
      });
    });
  }
};
