"use strict";

const common = require('../common');

const options = [
  {
    flags: '-m, --mode <mode>',
    description: 'The database to use for the query',
    autocomplete: ['QUICK', 'EXTENDED']
  }, {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

module.exports = {
  name: "repair <table...>",
  description: "Repairs a possibly corrupted table",
  options: options,
  autocomplete: common.autoCompleteTables,
  before: [common.validateConnection],
  action: function(args, cb) {
    const {table, options} = args;
    const query = `REPAIR TABLE ${table.join(',')} ${options.mode || ''}`;

    this.parent.query(query, options.db, cb, (results) => {
      this.log(`\n${common.printTable(results)}\n`);
      cb(null, results);
    });
  }
};
