'use strict';

const common = require('../common');

const options = [
  {
    flags: '-r, --regex <pattern>',
    description: 'Filter the result by RegExp'
  }, {
    flags: '-d, --db <name>',
    description: 'The database to use for the query',
    autocomplete: common.autoCompleteDatabases
  }
];

module.exports = {
  name: 'show columns <table>',
  description: 'Show the list of column in selected table',
  before: common.validateConnection,
  autocomplete: common.autoCompleteTables,
  options: options,
  action: function(args, cb) {
    const {table, options} = args;

    let query = `SHOW FULL COLUMNS FROM ${table}`;
    if (options.db) 
      query += ` IN ${options.db}`;
    if (options.regex) {
      options.regex = common.filterRegexOption(options.regex);
      query += ` LIKE '${options.regex}'`;
    }
    
    this.parent.query(query, options.db, cb, (results) => {
      this.log(`\n${common.printTable(results)}\n`);
      cb();
    });
  }
};
