'use strict';

const common = require('../common');

const options = [
  {
    flags: '-r, --regex <pattern>',
    description: 'Filter the result by RegExp'
  }
];

module.exports = {
  name: 'show tables [database]',
  description: 'Show the list of existing tables.',
  options: options,
  before: common.validateConnection,
  autocomplete: common.autoCompleteDatabases,
  action: function(args, cb) {
    const {appData, chalk} = this.parent;
    const {
      options,
      database = appData.currentDatabase
    } = args;
    if (!database || database === '') {
      return cb('You must select a database first.');
    }

    let query = `SHOW TABLES IN ${database}`;
    if (options.regex) {
      options.regex = common.filterRegexOption(options.regex);
      query += ` LIKE '${options.regex}'`;
    }

    this.parent.query(query, null, cb, (results) => {
      if (results.length === 0) {
        this.log(`There are ${chalk.yellow('no tables')} in ${chalk.green(database)}.`);
        return cb(null, []);
      }

      // Update session stored tables
      appData.databases[database].tables = results.map(r => r[`Tables_in_${database}`]);
      this.log(`\n${common.printTable(results)}\n`);
      cb(null, results);
    });
  }
};
