'use strict';

const common = require('../common');

const modifiers = ['GLOBAL', 'SESSION'];
const options = [
  {
    flags: '-r, --regex <pattern>',
    description: 'Filter the result by RegExp'
  }, {
    flags: '-m, --modifier <value>',
    description: 'Add the modifier variable to the query',
    autocomplete: modifiers,
    validate: v => modifiers.includes(v) || `You must enter one of ${modifiers.join(',')}`
  }
];

module.exports = {
  name: 'status',
  description: 'Get the server status',
  before: common.validateConnection,
  options: options,
  action: function(args, cb) {
    const {options} = args;
    const modifier = options.modifier || '';

    let query = `SHOW ${modifier} STATUS`;
    if (options.regex) {
      options.regex = common.filterRegexOption(options.regex);
      query += ` LIKE '${options.regex}'`;
    }

    this.parent.query(query, null, cb, (results) => {
      this.log(`\n${common.printTable(results)}\n`);
      cb(null, results);
    });
  }
};
