'use strict';

const chalk = require('chalk');
const asTable = require('as-table');

module.exports = {
  noop: () => {},
  filterRegexOption: function(v) {
    return v.indexOf('%') === -1
      ? `%${v}%`
      : v;
  },
  validateConnection: function() {
    const {conn} = this.parent;
    return new Promise((resolve, reject) => {
      if (!conn || conn === null || (conn.state !== 'connected' && conn.state !== 'authenticated')) {
        reject('You are not connected to any database.');
        return;
      }
      return resolve();
    });
  },
  validateDatabase: function() {
    return this.parent.appData.currentTable || 'You must select a database first.'
  },
  autoCompleteDatabases: function() {
    return Object.keys(this.appData.databases);
  },
  autoCompleteTables: function() {
    const database = this.appData.currentDatabase;
    if (!database || !this.appData.databases[database].tables) {
      return [];
    }
    return this.appData.databases[database].tables;
  },
  printTable: (data) => asTable.configure({
    title: v => chalk.bold(v),
    dash: '=',
    maxTotalWidth: process.stdout.columns
  })(data)
};
